@@ -1,24 +1,23 @@
 """
-Module for AMES-Cond atmospheric models.
+Module for AMES-Cond atmospheric model spectra.
 """
 
 import os
 import gzip
 import tarfile
+import urllib.request
 
-import wget
+import spectres
 import numpy as np
 
-from scipy.interpolate import interp1d
-
 from species.util import data_util
 
 
 def add_ames_cond(input_path,
                   database,
-                  wl_bound,
-                  teff_bound,
-                  specres):
+                  wavel_range,
+                  teff_range,
+                  spec_res):
     """
     Function for adding the AMES-Cond atmospheric models to the database.
 
@@ -28,11 +27,11 @@ def add_ames_cond(input_path,
         Folder where the data is located.
     database : h5py._hl.files.File
         Database.
-    wl_bound : tuple(float, float)
+    wavel_range : tuple(float, float)
         Wavelength range (micron).
-    teff_bound : tuple(float, float), None
+    teff_range : tuple(float, float), None
         Effective temperature range (K).
-    specres : float
+    spec_res : float
         Spectral resolution.
 
     Returns
@@ -41,9 +40,6 @@ def add_ames_cond(input_path,
         None
     """
 
-    if not wl_bound:
-        wl_bound = (1e-2, 1e2)
-
     if not os.path.exists(input_path):
         os.makedirs(input_path)
 
@@ -60,16 +56,14 @@ def add_ames_cond(input_path,
     data_file = os.path.join(data_folder, input_file)
 
     if not os.path.isfile(data_file):
-        print(f'Downloading AMES-Cond model spectra {label}...', end='')
-        wget.download(url, out=data_file, bar=None)
+        print(f'Downloading AMES-Cond model spectra {label}...', end='', flush=True)
+        urllib.request.urlretrieve(url, data_file)
         print(' [DONE]')
 
-    print(f'Unpacking AMES-Cond model spectra {label}...', end='')
-
+    print(f'Unpacking AMES-Cond model spectra {label}...', end='', flush=True)
     tar = tarfile.open(data_file)
     tar.extractall(data_folder)
     tar.close()
-
     print(' [DONE]')
 
     data_folder += 'SPECTRA/'
@@ -78,10 +72,10 @@ def add_ames_cond(input_path,
     logg = []
     flux = []
 
-    wavelength = [wl_bound[0]]
+    wavelength = [wavel_range[0]]
 
-    while wavelength[-1] <= wl_bound[1]:
-        wavelength.append(wavelength[-1] + wavelength[-1]/specres)
+    while wavelength[-1] <= wavel_range[1]:
+        wavelength.append(wavelength[-1] + wavelength[-1]/spec_res)
 
     wavelength = np.asarray(wavelength[:-1])
 
@@ -89,9 +83,6 @@ def add_ames_cond(input_path,
         for filename in sorted(file_list):
 
             if filename.startswith('lte') and filename.endswith('.gz'):
-                print_message = f'Adding AMES-Cond model spectra... {filename}'
-                print(f'\r{print_message:<80}', end='')
-
                 teff_val = float(filename[3:5])*100.
                 logg_val = float(filename[6:9])
                 feh_val = float(filename[10:13])
@@ -99,10 +90,13 @@ def add_ames_cond(input_path,
                 if feh_val != 0.:
                     continue
 
-                if teff_bound is not None:
-                    if teff_val < teff_bound[0] or teff_val > teff_bound[1]:
+                if teff_range is not None:
+                    if teff_val < teff_range[0] or teff_val > teff_range[1]:
                         continue
 
+                print_message = f'Adding AMES-Cond model spectra... {filename}'
+                print(f'\r{print_message:<71}', end='')
+
                 data_wavel = []
                 data_flux = []
 
@@ -169,22 +163,13 @@ def add_ames_cond(input_path,
                 if np.all(np.diff(data[:, 0]) < 0):
                     raise ValueError('The wavelengths are not all sorted by increasing value.')
 
-                indices = np.where((data[:, 0] >= wl_bound[0]) &
-                                   (data[:, 0] <= wl_bound[1]))[0]
+                teff.append(teff_val)
+                logg.append(logg_val)
 
-                if indices.size > 0:
-                    teff.append(teff_val)
-                    logg.append(logg_val)
-
-                    data = data[indices, :]
-
-                    flux_interp = interp1d(data[:, 0],
-                                           data[:, 1],
-                                           kind='linear',
-                                           bounds_error=False,
-                                           fill_value=1e-100)
-
-                    flux.append(flux_interp(wavelength))
+                try:
+                    flux.append(spectres.spectres(wavelength, data[:, 0], data[:, 1]))
+                except ValueError:
+                    flux.append(np.zeros(wavelength.shape[0]))
 
     data_sorted = data_util.sort_data(np.asarray(teff),
                                       np.asarray(logg),
@@ -194,7 +179,7 @@ def add_ames_cond(input_path,
                                       wavelength,
                                       np.asarray(flux))
 
-    data_util.write_data('ames-cond', ('teff', 'logg'), database, data_sorted)
+    data_util.write_data('ames-cond', ['teff', 'logg'], database, data_sorted)
 
     print_message = 'Adding AMES-Cond model spectra... [DONE]'
-    print(f'\r{print_message:<80}')
+    print(f'\r{print_message:<71}')
