@@ -1,25 +1,23 @@
 """
-Module for BT-NextGen atmospheric models.
+Module for BT-NextGen atmospheric model spectra.
 """
 
 import os
-import sys
 import tarfile
+import urllib.request
 
-import wget
+import spectres
 import numpy as np
 import pandas as pd
 
-from scipy.interpolate import interp1d
-
 from species.util import data_util
 
 
 def add_btnextgen(input_path,
                   database,
-                  wl_bound,
-                  teff_bound,
-                  specres):
+                  wavel_range,
+                  teff_range,
+                  spec_res):
     """
     Function for adding the BT-NextGen atmospheric models to the database.
 
@@ -29,11 +27,11 @@ def add_btnextgen(input_path,
         Folder where the data is located.
     database : h5py._hl.files.File
         Database.
-    wl_bound : tuple(float, float)
+    wavel_range : tuple(float, float)
         Wavelength range (micron).
-    teff_bound : tuple(float, float), None
+    teff_range : tuple(float, float), None
         Effective temperature range (K).
-    specres : float
+    spec_res : float
         Spectral resolution.
 
     Returns
@@ -42,9 +40,6 @@ def add_btnextgen(input_path,
         None
     """
 
-    if not wl_bound:
-        wl_bound = (1e-2, 1e2)
-
     if not os.path.exists(input_path):
         os.makedirs(input_path)
 
@@ -66,33 +61,25 @@ def add_btnextgen(input_path,
         data_file = os.path.join(input_path, item)
 
         if not os.path.isfile(data_file):
-            sys.stdout.write('Downloading BT-NextGen model spectra '+labels[i]+'...')
-            sys.stdout.flush()
-
-            wget.download(urls[i], out=data_file, bar=None)
-
-            sys.stdout.write(' [DONE]\n')
-            sys.stdout.flush()
-
-        sys.stdout.write('Unpacking BT-NextGen model spectra '+labels[i]+'...')
-        sys.stdout.flush()
+            print(f'Downloading BT-NextGen model spectra {labels[i]}...', end='', flush=True)
+            urllib.request.urlretrieve(urls[i], data_file)
+            print(' [DONE]')
 
+        print(f'Unpacking BT-NextGen model spectra {labels[i]}...', end='', flush=True)
         tar = tarfile.open(data_file)
         tar.extractall(data_folder)
         tar.close()
-
-        sys.stdout.write(' [DONE]\n')
-        sys.stdout.flush()
+        print(' [DONE]')
 
     teff = []
     logg = []
     feh = []
     flux = []
 
-    wavelength = [wl_bound[0]]
+    wavelength = [wavel_range[0]]
 
-    while wavelength[-1] <= wl_bound[1]:
-        wavelength.append(wavelength[-1] + wavelength[-1]/specres)
+    while wavelength[-1] <= wavel_range[1]:
+        wavelength.append(wavelength[-1] + wavelength[-1]/spec_res)
 
     wavelength = np.asarray(wavelength[:-1])
 
@@ -100,21 +87,17 @@ def add_btnextgen(input_path,
         for filename in sorted(file_list):
 
             if filename.startswith('lte') and filename.endswith('.7.bz2'):
-                sys.stdout.write('\rAdding BT-NextGen model spectra... '+filename)
-                sys.stdout.flush()
-
                 teff_val = float(filename[3:6])*100.
+                logg_val = float(filename[7:9])
+                feh_val = float(filename[11:14])
 
-                if teff_bound is not None:
-
-                    if teff_bound[0] <= teff_val <= teff_bound[1]:
-                        teff.append(teff_val)
-                        logg.append(float(filename[7:9]))
-                        feh.append(float(filename[11:14]))
-
-                    else:
+                if teff_range is not None:
+                    if teff_val < teff_range[0] or teff_val > teff_range[1]:
                         continue
 
+                print_message = f'Adding BT-NextGen model spectra... {filename}'
+                print(f'\r{print_message:<80}', end='')
+
                 dataf = pd.pandas.read_csv(data_folder+filename,
                                            usecols=[0, 1],
                                            names=['wavelength', 'flux'],
@@ -146,18 +129,14 @@ def add_btnextgen(input_path,
                 if np.all(np.diff(data[0, :]) < 0):
                     raise ValueError('The wavelengths are not all sorted by increasing value.')
 
-                indices = np.where((data[0, :] >= wl_bound[0]) &
-                                   (data[0, :] <= wl_bound[1]))[0]
+                teff.append(teff_val)
+                logg.append(logg_val)
+                feh.append(feh_val)
 
-                data = data[:, indices]
-
-                flux_interp = interp1d(data[0, :],
-                                       data[1, :],
-                                       kind='linear',
-                                       bounds_error=False,
-                                       fill_value=1e-100)
-
-                flux.append(flux_interp(wavelength))
+                try:
+                    flux.append(spectres.spectres(wavelength, data[:, 0], data[:, 1]))
+                except ValueError:
+                    flux.append(np.zeros(wavelength.shape[0]))
 
     data_sorted = data_util.sort_data(np.asarray(teff),
                                       np.asarray(logg),
@@ -169,7 +148,5 @@ def add_btnextgen(input_path,
 
     data_util.write_data('bt-nextgen', ('teff', 'logg', 'feh'), database, data_sorted)
 
-    sys.stdout.write('\rAdding BT-NextGen model spectra... [DONE]'
-                     '                              \n')
-
-    sys.stdout.flush()
+    print_message = 'Adding BT-NextGen model spectra... [DONE]'
+    print(f'\r{print_message:<80}')
