@@ -1,12 +1,11 @@
 """
-Module for DRIFT-PHOENIX atmospheric models.
+Module for DRIFT-PHOENIX atmospheric model spectra.
 """
 
 import os
-import sys
 import tarfile
+import urllib.request
 
-import wget
 import numpy as np
 
 from species.util import data_util
@@ -20,7 +19,9 @@ def add_drift_phoenix(input_path,
     Parameters
     ----------
     input_path : str
+        Folder where the data is located.
     database : h5py._hl.files.File
+        Database.
 
     Returns
     -------
@@ -37,23 +38,15 @@ def add_drift_phoenix(input_path,
     url = 'https://people.phys.ethz.ch/~stolkert/species/drift-phoenix.tgz'
 
     if not os.path.isfile(data_file):
-        sys.stdout.write('Downloading DRIFT-PHOENIX model spectra (151 MB)...')
-        sys.stdout.flush()
-
-        wget.download(url, out=data_file, bar=None)
-
-        sys.stdout.write(' [DONE]\n')
-        sys.stdout.flush()
-
-    sys.stdout.write('Unpacking DRIFT-PHOENIX model spectra...')
-    sys.stdout.flush()
+        print('Downloading DRIFT-PHOENIX model spectra (151 MB)...', end='', flush=True)
+        urllib.request.urlretrieve(url, data_file)
+        print(' [DONE]')
 
+    print('Unpacking DRIFT-PHOENIX model spectra...', end='', flush=True)
     tar = tarfile.open(data_file)
     tar.extractall(input_path)
     tar.close()
-
-    sys.stdout.write(' [DONE]\n')
-    sys.stdout.flush()
+    print(' [DONE]')
 
     teff = []
     logg = []
@@ -65,8 +58,8 @@ def add_drift_phoenix(input_path,
         for filename in sorted(file_list):
 
             if filename.startswith('lte_'):
-                sys.stdout.write('\rAdding DRIFT-PHOENIX model spectra... '+filename)
-                sys.stdout.flush()
+                print_message = f'Adding DRIFT-PHOENIX model spectra... {filename}'
+                print(f'\r{print_message:<65}', end='')
 
                 teff.append(float(filename[4:8]))
                 logg.append(float(filename[9:12]))
@@ -94,5 +87,5 @@ def add_drift_phoenix(input_path,
 
     data_util.write_data('drift-phoenix', ('teff', 'logg', 'feh'), database, data_sorted)
 
-    sys.stdout.write('\rAdding DRIFT-PHOENIX model spectra... [DONE]                    \n')
-    sys.stdout.flush()
+    print_message = 'Adding DRIFT-PHOENIX model spectra... [DONE]'
+    print(f'\r{print_message:<65}')
