@@ -3,10 +3,9 @@ Module for adding IRTF spectra tot the database.
 """
 
 import os
-import sys
 import tarfile
+import urllib.request
 
-import wget
 import numpy as np
 
 from astropy.io import fits
@@ -73,24 +72,18 @@ def add_irtf(input_path,
 
     for item in sptypes:
         if not os.path.isfile(data_file[item]):
-            sys.stdout.write('Downloading IRTF Spectral Library - '+data_type[item]+'...')
-            sys.stdout.flush()
+            print(f'Downloading IRTF Spectral Library - {data_type[item]}...', end='', flush=True)
+            urllib.request.urlretrieve(url[item], data_file[item])
+            print(' [DONE]')
 
-            wget.download(url[item], out=data_file[item], bar=None)
-
-            sys.stdout.write(' [DONE]\n')
-            sys.stdout.flush()
-
-    sys.stdout.write('Unpacking IRTF Spectral Library...')
-    sys.stdout.flush()
+    print('Unpacking IRTF Spectral Library...', end='', flush=True)
 
     for item in sptypes:
         tar = tarfile.open(data_file[item])
         tar.extractall(path=datadir)
         tar.close()
 
-    sys.stdout.write(' [DONE]\n')
-    sys.stdout.flush()
+    print(' [DONE]')
 
     database.create_group('spectra/irtf')
 
@@ -113,23 +106,22 @@ def add_irtf(input_path,
                     spt_split = sptype.split()
 
                     if item in ['L', 'T'] or spt_split[1][0] == 'V':
-                        sys.stdout.write('\rAdding IRTF Spectral Library... '+'{:<40}'.format(name))
-                        sys.stdout.flush()
+                        print_message = f'Adding IRTF Spectral Library... {name}'
+                        print(f'\r{print_message:<80}', end='')
 
                         simbad_id, distance = queries.get_distance(name)  # [pc]
 
                         sptype = data_util.update_sptype(np.array([sptype]))[0]
 
                         dset = database.create_dataset('spectra/irtf/'+name,
-                                                       data=spdata,
-                                                       dtype='f')
+                                                       data=spdata)
 
                         dset.attrs['name'] = str(name).encode()
                         dset.attrs['sptype'] = str(sptype).encode()
                         dset.attrs['simbad'] = str(simbad_id).encode()
                         dset.attrs['distance'] = distance
 
-    sys.stdout.write('\rAdding IRTF Spectral Library... '+'{:<40}'.format('[DONE]')+'\n')
-    sys.stdout.flush()
+    print_message = 'Adding IRTF Spectral Library... [DONE]'
+    print(f'\r{print_message:<80}')
 
     database.close()
