@@ -3,9 +3,8 @@ Text
 """
 
 import os
-import sys
+import urllib.request
 
-import wget
 import h5py
 import numpy as np
 import pandas as pd
@@ -38,25 +37,16 @@ def add_leggett(input_path,
     url2 = 'http://staff.gemini.edu/~sleggett/datafile8.txt'
 
     if not os.path.isfile(data_file1):
-        sys.stdout.write('Downloading Leggett L and T Dwarf Data (88 kB)...')
-        sys.stdout.flush()
-
-        wget.download(url1, out=data_file1, bar=None)
-
-        sys.stdout.write(' [DONE]\n')
-        sys.stdout.flush()
+        print('Downloading Leggett L and T Dwarf Data (88 kB)...', end='', flush=True)
+        urllib.request.urlretrieve(url1, data_file1)
+        print(' [DONE]')
 
     if not os.path.isfile(data_file2):
-        sys.stdout.write('Downloading Leggett T6+ and Y Dwarf Data (44 kB)...')
-        sys.stdout.flush()
+        print('Downloading Leggett T6+ and Y Dwarf Data (44 kB)...', end='', flush=True)
+        urllib.request.urlretrieve(url2, data_file2)
+        print(' [DONE]')
 
-        wget.download(url2, out=data_file2, bar=None)
-
-        sys.stdout.write(' [DONE]\n')
-        sys.stdout.flush()
-
-    sys.stdout.write('Adding Leggett L and T Dwarf Data...')
-    sys.stdout.flush()
+    print('Adding Leggett L and T Dwarf Data...', end='', flush=True)
 
     group = 'photometry/leggett'
 
@@ -88,11 +78,8 @@ def add_leggett(input_path,
     mag_w3 = np.repeat(np.nan, np.size(name))
     mag_w4 = np.repeat(np.nan, np.size(name))
 
-    sys.stdout.write(' [DONE]\n')
-    sys.stdout.flush()
-
-    sys.stdout.write('Adding Leggett T6+ and Y Dwarf Data...')
-    sys.stdout.flush()
+    print(' [DONE]')
+    print('Adding Leggett T6+ and Y Dwarf Data...', end='', flush=True)
 
     file_io = open(data_file2, 'r')
     lines = file_io.readlines()[69:]
@@ -165,23 +152,22 @@ def add_leggett(input_path,
     dset = database.create_dataset(group+'/flag', (np.size(flag), ), dtype=dtype)
     dset[...] = flag
 
-    database.create_dataset(group+'/distance', data=distance, dtype='f')
-    database.create_dataset(group+'/MKO/NSFCam.Y', data=mag_y, dtype='f')
-    database.create_dataset(group+'/MKO/NSFCam.J', data=mag_j, dtype='f')
-    database.create_dataset(group+'/MKO/NSFCam.H', data=mag_h, dtype='f')
-    database.create_dataset(group+'/MKO/NSFCam.K', data=mag_k, dtype='f')
-    database.create_dataset(group+'/MKO/NSFCam.Lp', data=mag_lp, dtype='f')
-    database.create_dataset(group+'/MKO/NSFCam.Mp', data=mag_mp, dtype='f')
-    database.create_dataset(group+'/Spitzer/IRAC.I1', data=mag_ch1, dtype='f')
-    database.create_dataset(group+'/Spitzer/IRAC.I2', data=mag_ch2, dtype='f')
-    database.create_dataset(group+'/Spitzer/IRAC.I3', data=mag_ch3, dtype='f')
-    database.create_dataset(group+'/Spitzer/IRAC.I4', data=mag_ch4, dtype='f')
-    database.create_dataset(group+'/WISE/WISE.W1', data=mag_w1, dtype='f')
-    database.create_dataset(group+'/WISE/WISE.W2', data=mag_w2, dtype='f')
-    database.create_dataset(group+'/WISE/WISE.W3', data=mag_w3, dtype='f')
-    database.create_dataset(group+'/WISE/WISE.W4', data=mag_w4, dtype='f')
+    database.create_dataset(group+'/distance', data=distance)
+    database.create_dataset(group+'/MKO/NSFCam.Y', data=mag_y)
+    database.create_dataset(group+'/MKO/NSFCam.J', data=mag_j)
+    database.create_dataset(group+'/MKO/NSFCam.H', data=mag_h)
+    database.create_dataset(group+'/MKO/NSFCam.K', data=mag_k)
+    database.create_dataset(group+'/MKO/NSFCam.Lp', data=mag_lp)
+    database.create_dataset(group+'/MKO/NSFCam.Mp', data=mag_mp)
+    database.create_dataset(group+'/Spitzer/IRAC.I1', data=mag_ch1)
+    database.create_dataset(group+'/Spitzer/IRAC.I2', data=mag_ch2)
+    database.create_dataset(group+'/Spitzer/IRAC.I3', data=mag_ch3)
+    database.create_dataset(group+'/Spitzer/IRAC.I4', data=mag_ch4)
+    database.create_dataset(group+'/WISE/WISE.W1', data=mag_w1)
+    database.create_dataset(group+'/WISE/WISE.W2', data=mag_w2)
+    database.create_dataset(group+'/WISE/WISE.W3', data=mag_w3)
+    database.create_dataset(group+'/WISE/WISE.W4', data=mag_w4)
 
-    sys.stdout.write(' [DONE]\n')
-    sys.stdout.flush()
+    print(' [DONE]')
 
     database.close()
