@@ -4,6 +4,7 @@ Module with reading functionalities for atmospheric model spectra.
 
 import os
 import math
+import warnings
 import configparser
 
 import h5py
@@ -112,7 +113,7 @@ class ReadModel:
             wavelength point was used.
         """
 
-        wl_points = np.asarray(hdf5_file['models/'+self.model+'/wavelength'])
+        wl_points = np.asarray(hdf5_file[f'models/{self.model}/wavelength'])
 
         if self.wavel_range is None:
             wl_index = np.ones(wl_points.shape[0], dtype=bool)
@@ -141,23 +142,23 @@ class ReadModel:
 
         h5_file = self.open_database()
 
-        flux = np.asarray(h5_file['models/'+self.model+'/flux'])
-        teff = np.asarray(h5_file['models/'+self.model+'/teff'])
-        logg = np.asarray(h5_file['models/'+self.model+'/logg'])
+        flux = np.asarray(h5_file[f'models/{self.model}/flux'])
+        teff = np.asarray(h5_file[f'models/{self.model}/teff'])
+        logg = np.asarray(h5_file[f'models/{self.model}/logg'])
 
         if self.wl_points is None:
             self.wl_points, self.wl_index = self.wavelength_points(h5_file)
 
-        if self.model in ('drift-phoenix', 'bt-nextgen', 'petitcode-cool-clear'):
+        if self.model in ['ames-cond', 'ames-dusty', 'bt-settl']:
+            points = (teff, logg)
+            flux = flux[:, :, self.wl_index]
+
+        if self.model in ['bt-nextgen', 'drift-phoenix', 'petitcode-cool-clear']:
             feh = np.asarray(h5_file['models/'+self.model+'/feh'])
 
             points = (teff, logg, feh)
             flux = flux[:, :, :, self.wl_index]
 
-        elif self.model in ('bt-settl', 'ames-dusty', 'ames-cond'):
-            points = (teff, logg)
-            flux = flux[:, :, self.wl_index]
-
         elif self.model == 'petitcode-cool-cloudy':
             feh = np.asarray(h5_file['models/petitcode-cool-cloudy/feh'])
             fsed = np.asarray(h5_file['models/petitcode-cool-cloudy/fsed'])
@@ -191,7 +192,9 @@ class ReadModel:
     def get_model(self,
                   model_param,
                   spec_res=None,
-                  magnitude=False):
+                  wavel_resample=None,
+                  magnitude=False,
+                  smooth=False):
         """
         Function for extracting a model spectrum by linearly interpolating the model grid. The
         parameters values should lie within the boundaries of the grid points that are stored
@@ -201,13 +204,23 @@ class ReadModel:
         Parameters
         ----------
         model_param : dict
-            Model parameters and values.
+            Model parameters and values. The values should be within the boundaries of the grid.
+            The grid boundaries of the available spectra in the database can be obtained with
+            :func:`~species.read.read_model.ReadModel.get_bounds()`.
         spec_res : float, None
             Spectral resolution, achieved by smoothing with a Gaussian kernel. The original
-            wavelength points are used if set to None.
+            wavelength points are used if both ``spec_res`` and ``wavel_resample`` are set to None.
+        wavel_resample : numpy.ndarray
+            Wavelength points (micron) to which the spectrum is resampled. Only used if
+            ``spec_res`` is set to None.
         magnitude : bool
             Normalize the spectrum with a flux calibrated spectrum of Vega and return the magnitude
             instead of flux density.
+        smooth : bool
+            If True, the spectral resolution is changed by smoothing with a Gaussian kernel. In
+            that case the original wavelength grid is maintained. Note that this requires
+            equally-spaced wavelength bins. If False, the spectrum is resampled by linearly
+            interpolating the extracted spectrum. Only used if ``spec_res`` is not None.
 
         Returns
         -------
@@ -215,6 +228,32 @@ class ReadModel:
             Box with the model spectrum.
         """
 
+        if spec_res is not None and wavel_resample is not None:
+            raise ValueError('The \'spec_res\' and \'wavel_resample\' parameters can not be used '
+                             'simultaneously. Please set one of them to None.')
+
+        if smooth and wavel_resample is not None:
+            warnings.warn('The \'smooth\' parameter is ignored because it can only be used in '
+                          'combination with \'spec_res\'.')
+
+        grid_bounds = self.get_bounds()
+
+        for key, value in model_param.items():
+            if key not in ['radius', 'distance', 'mass', 'luminosity']:
+                if key not in self.get_parameters():
+                    raise ValueError(f'The \'{key}\' parameter is not required by \'{self.model}\''
+                                     f'. The mandatory parameters are {self.get_parameters()}.')
+
+                if value < grid_bounds[key][0]:
+                    raise ValueError(f'The input value of \'{key}\' is smaller than the lower '
+                                     f'boundary of the model grid ({value} < '
+                                     f'{grid_bounds[key][0]}).')
+
+                if value > grid_bounds[key][1]:
+                    raise ValueError(f'The input value of \'{key}\' is larger than the upper '
+                                     f'boundary of the model grid ({value} > '
+                                     f'{grid_bounds[key][1]}).')
+
         if 'mass' in model_param:
             mass = 1e3 * model_param['mass'] * constants.M_JUP  # [g]
             radius = math.sqrt(1e3 * constants.GRAVITY * mass / (10.**model_param['logg']))  # [cm]
@@ -227,15 +266,15 @@ class ReadModel:
             wl_points = self.get_wavelengths()
             self.wavel_range = (wl_points[0], wl_points[-1])
 
-        if self.model in ('drift-phoenix', 'bt-nextgen', 'petitcode-cool-clear'):
+        if self.model in ['ames-cond', 'ames-dusty', 'bt-settl']:
+            parameters = [model_param['teff'],
+                          model_param['logg']]
+
+        elif self.model in ['bt-nextgen', 'drift-phoenix', 'petitcode-cool-clear']:
             parameters = [model_param['teff'],
                           model_param['logg'],
                           model_param['feh']]
 
-        elif self.model in ('bt-settl', 'ames-dusty', 'ames-cond'):
-            parameters = [model_param['teff'],
-                          model_param['logg']]
-
         elif self.model == 'petitcode-cool-cloudy':
             parameters = [model_param['teff'],
                           model_param['logg'],
@@ -266,7 +305,12 @@ class ReadModel:
 
                 flux *= scaling
 
-        if spec_res is not None:
+        if spec_res is None and wavel_resample is not None:
+            flux = spectres.spectres(new_spec_wavs=wavel_resample,
+                                     old_spec_wavs=self.wl_points,
+                                     spec_fluxes=flux)
+
+        elif spec_res is not None:
             index = np.where(np.isnan(flux))[0]
 
             if index.size > 0:
@@ -274,10 +318,36 @@ class ReadModel:
                                  'the parameter values and the wavelength range are within '
                                  'the grid boundaries as stored in the database.')
 
-            flux = read_util.smooth_spectrum(wavelength=self.wl_points,
-                                             flux=flux,
-                                             spec_res=spec_res,
-                                             size=11)
+            if smooth:
+                flux = read_util.smooth_spectrum(wavelength=self.wl_points,
+                                                 flux=flux,
+                                                 spec_res=spec_res,
+                                                 size=11)
+
+            else:
+                wavel_resample = [self.wl_points[0]]
+                while wavel_resample[-1] <= self.wl_points[-1]:
+                    wavel_resample.append(wavel_resample[-1] + wavel_resample[-1]/spec_res)
+
+                wavel_resample = np.asarray(wavel_resample[:-1])
+
+                indices = np.where((wavel_resample > self.wl_points[0]) &
+                                   (wavel_resample < self.wl_points[-2]))[0]
+
+                for i in range(10):
+                    try:
+                        index_error = False
+
+                        flux = spectres.spectres(new_spec_wavs=wavel_resample[indices][i:-i],
+                                                 old_spec_wavs=self.wl_points,
+                                                 spec_fluxes=flux)
+
+                    except ValueError:
+                        index_error = True
+
+                    if not index_error:
+                        wavel_resample = wavel_resample[indices][i:-i]
+                        break
 
         if magnitude:
             quantity = 'magnitude'
@@ -307,9 +377,14 @@ class ReadModel:
 
         is_finite = np.where(np.isfinite(flux))[0]
 
+        if wavel_resample is None:
+            wavelength = self.wl_points[is_finite]
+        else:
+            wavelength = wavel_resample[is_finite]
+
         return box.create_box(boxtype='model',
                               model=self.model,
-                              wavelength=self.wl_points[is_finite],
+                              wavelength=wavelength,
                               flux=flux[is_finite],
                               parameters=model_param,
                               quantity=quantity)
@@ -333,79 +408,116 @@ class ReadModel:
             Box with the model spectrum.
         """
 
+        for key in model_param:
+            if key not in ['radius', 'distance', 'mass', 'luminosity']:
+                if key not in self.get_parameters():
+                    raise ValueError(f'The \'{key}\' parameter is not required by \'{self.model}\''
+                                     f'. The mandatory parameters are {self.get_parameters()}.')
+
         h5_file = self.open_database()
 
         wl_points, wl_index = self.wavelength_points(h5_file)
 
-        flux = np.asarray(h5_file['models/'+self.model+'/flux'])
-        teff = np.asarray(h5_file['models/'+self.model+'/teff'])
-        logg = np.asarray(h5_file['models/'+self.model+'/logg'])
+        flux = np.asarray(h5_file[f'models/{self.model}/flux'])
+        teff = np.asarray(h5_file[f'models/{self.model}/teff'])
+        logg = np.asarray(h5_file[f'models/{self.model}/logg'])
 
-        if self.model in ('bt-settl', 'ames-cond', 'ames-dusty'):
+        if self.model in ['ames-cond', 'ames-dusty', 'bt-settl']:
             teff_index = np.argwhere(teff == model_param['teff'])[0]
 
-            if not teff_index:
+            if len(teff_index) == 0:
                 raise ValueError('Temperature value not found.')
 
             teff_index = teff_index[0]
             logg_index = np.argwhere(logg == model_param['logg'])[0]
 
-            if not logg_index:
+            if len(logg_index) == 0:
                 raise ValueError('Surface gravity value not found.')
 
             logg_index = logg_index[0]
 
             flux = flux[teff_index, logg_index, wl_index]
 
-        elif self.model in ('drift-phoenix', 'bt-nextgen'):
+        elif self.model in ['bt-nextgen', 'drift-phoenix', 'petitcode-cool-clear']:
             feh = np.asarray(h5_file['models/'+self.model+'/feh'])
 
             teff_index = np.argwhere(teff == model_param['teff'])[0]
 
-            if not teff_index:
+            if len(teff_index) == 0:
                 raise ValueError('Temperature value not found.')
 
             teff_index = teff_index[0]
             logg_index = np.argwhere(logg == model_param['logg'])[0]
 
-            if not logg_index:
+            if len(logg_index) == 0:
                 raise ValueError('Surface gravity value not found.')
 
             logg_index = logg_index[0]
             feh_index = np.argwhere(feh == model_param['feh'])[0]
 
-            if not feh_index:
+            if len(feh_index) == 0:
                 raise ValueError('Metallicity value not found.')
 
             feh_index = feh_index[0]
 
             flux = flux[teff_index, logg_index, feh_index, wl_index]
 
+        elif self.model == 'petitcode-cool-cloudy':
+            feh = np.asarray(h5_file['models/'+self.model+'/feh'])
+            fsed = np.asarray(h5_file['models/'+self.model+'/fsed'])
+
+            teff_index = np.argwhere(teff == model_param['teff'])[0]
+
+            if len(teff_index) == 0:
+                raise ValueError('Temperature value not found.')
+
+            teff_index = teff_index[0]
+            logg_index = np.argwhere(logg == model_param['logg'])[0]
+
+            if len(logg_index) == 0:
+                raise ValueError('Surface gravity value not found.')
+
+            logg_index = logg_index[0]
+            feh_index = np.argwhere(feh == model_param['feh'])[0]
+
+            if len(feh_index) == 0:
+                raise ValueError('Metallicity value not found.')
+
+            feh_index = feh_index[0]
+            fsed_index = np.argwhere(fsed == model_param['fsed'])[0]
+
+            if len(fsed_index) == 0:
+                raise ValueError('f_sed value not found.')
+
+            fsed_index = fsed_index[0]
+
+            flux = flux[teff_index, logg_index, feh_index, fsed_index, wl_index]
+
         elif self.model == 'petitcode-hot-clear':
             feh = np.asarray(h5_file['models/'+self.model+'/feh'])
             co_ratio = np.asarray(h5_file['models/'+self.model+'/co'])
 
             teff_index = np.argwhere(teff == model_param['teff'])[0]
 
-            if not teff_index:
+            if len(teff_index) == 0:
                 raise ValueError('Temperature value not found.')
 
             teff_index = teff_index[0]
             logg_index = np.argwhere(logg == model_param['logg'])[0]
 
-            if not logg_index:
+            if len(logg_index) == 0:
                 raise ValueError('Surface gravity value not found.')
 
             logg_index = logg_index[0]
             feh_index = np.argwhere(feh == model_param['feh'])[0]
 
-            if not feh_index:
+            if len(feh_index) == 0:
                 raise ValueError('Metallicity value not found.')
 
             feh_index = feh_index[0]
             co_index = np.argwhere(co_ratio == model_param['co'])[0]
 
-            if not co_index:
+            if len(co_index) == 0:
                 raise ValueError('C/O value not found.')
 
             co_index = co_index[0]
@@ -419,31 +531,31 @@ class ReadModel:
 
             teff_index = np.argwhere(teff == model_param['teff'])[0]
 
-            if not teff_index:
+            if len(teff_index) == 0:
                 raise ValueError('Temperature value not found.')
 
             teff_index = teff_index[0]
             logg_index = np.argwhere(logg == model_param['logg'])[0]
 
-            if not logg_index:
+            if len(logg_index) == 0:
                 raise ValueError('Surface gravity value not found.')
 
             logg_index = logg_index[0]
             feh_index = np.argwhere(feh == model_param['feh'])[0]
 
-            if not feh_index:
+            if len(feh_index) == 0:
                 raise ValueError('Metallicity value not found.')
 
             feh_index = feh_index[0]
             co_index = np.argwhere(co_ratio == model_param['co'])[0]
 
-            if not co_index:
+            if len(co_index) == 0:
                 raise ValueError('C/O value not found.')
 
             co_index = co_index[0]
             fsed_index = np.argwhere(fsed == model_param['fsed'])[0]
 
-            if not fsed_index:
+            if len(fsed_index) == 0:
                 raise ValueError('f_sed value not found.')
 
             fsed_index = fsed_index[0]
@@ -515,23 +627,28 @@ class ReadModel:
         if self.spectrum_interp is None:
             self.interpolate_model()
 
-        spectrum = self.get_model(model_param, None)
-        synphot = photometry.SyntheticPhotometry(self.filter_name)
+        try:
+            spectrum = self.get_model(model_param, None)
+        except ValueError:
+            warnings.warn(f'The set of model parameters {model_param} is outside the grid range '
+                          f'{self.get_bounds()} so returning a NaN.')
+
+            return np.nan, np.nan
 
         if spectrum.wavelength.size == 0:
             app_mag = np.nan
             abs_mag = np.nan
 
         else:
+            synphot = photometry.SyntheticPhotometry(self.filter_name)
+
             if 'distance' in model_param:
-                app_mag, abs_mag = synphot.spectrum_to_magnitude(spectrum.wavelength,
-                                                                 spectrum.flux,
-                                                                 distance=model_param['distance'])
+                app_mag, abs_mag = synphot.spectrum_to_magnitude(
+                    spectrum.wavelength, spectrum.flux, distance=model_param['distance'])
 
             else:
-                app_mag, abs_mag = synphot.spectrum_to_magnitude(spectrum.wavelength,
-                                                                 spectrum.flux,
-                                                                 distance=None)
+                app_mag, abs_mag = synphot.spectrum_to_magnitude(
+                    spectrum.wavelength, spectrum.flux, distance=None)
 
         return app_mag, abs_mag
 
@@ -550,18 +667,18 @@ class ReadModel:
         teff = h5_file['models/'+self.model+'/teff']
         logg = h5_file['models/'+self.model+'/logg']
 
-        if self.model in ('ames-cond', 'ames-dusty', 'bt-settl'):
+        if self.model in ['ames-cond', 'ames-dusty', 'bt-settl']:
             bounds = {'teff': (teff[0], teff[-1]),
                       'logg': (logg[0], logg[-1])}
 
-        elif self.model in ('drift-phoenix', 'bt-nextgen', 'petitcode-cool-clear'):
+        elif self.model in ['drift-phoenix', 'bt-nextgen', 'petitcode-cool-clear']:
             feh = h5_file['models/'+self.model+'/feh']
 
             bounds = {'teff': (teff[0], teff[-1]),
                       'logg': (logg[0], logg[-1]),
                       'feh': (feh[0], feh[-1])}
 
-        elif self.model in ('petitcode-cool-cloudy', ):
+        elif self.model in ['petitcode-cool-cloudy', ]:
             feh = h5_file['models/'+self.model+'/feh']
             fsed = h5_file['models/'+self.model+'/fsed']
 
@@ -570,7 +687,7 @@ class ReadModel:
                       'feh': (feh[0], feh[-1]),
                       'fsed': (fsed[0], fsed[-1])}
 
-        elif self.model in ('petitcode-hot-clear', ):
+        elif self.model in ['petitcode-hot-clear', ]:
             feh = h5_file['models/'+self.model+'/feh']
             co_ratio = h5_file['models/'+self.model+'/co']
 
@@ -579,7 +696,7 @@ class ReadModel:
                       'feh': (feh[0], feh[-1]),
                       'co': (co_ratio[0], co_ratio[-1])}
 
-        elif self.model in ('petitcode-hot-cloudy', ):
+        elif self.model in ['petitcode-hot-cloudy', ]:
             feh = h5_file['models/'+self.model+'/feh']
             co_ratio = h5_file['models/'+self.model+'/co']
             fsed = h5_file['models/'+self.model+'/fsed']
@@ -624,16 +741,31 @@ class ReadModel:
 
         h5_file = self.open_database()
 
-        teff = h5_file['models/'+self.model+'/teff']
-        logg = h5_file['models/'+self.model+'/logg']
+        teff = h5_file[f'models/{self.model}/teff']
+        logg = h5_file[f'models/{self.model}/logg']
 
         points['teff'] = np.asarray(teff)
         points['logg'] = np.asarray(logg)
 
-        if self.model in ('drift-phoenix', 'bt-nextgen'):
-            feh = h5_file['models/'+self.model+'/feh']
+        feh_models = ['drift-phoenix',
+                      'bt-nextgen',
+                      'petitcode-cool-clear',
+                      'petitcode-cool-cloudy',
+                      'petitcode-hot-clear',
+                      'petitcode-hot-cloudy']
+
+        if self.model in feh_models:
+            feh = h5_file[f'models/{self.model}/feh']
             points['feh'] = np.asarray(feh)
 
+        if self.model in ['petitcode-cool-cloudy', 'petitcode-hot-cloudy']:
+            fsed = h5_file[f'models/{self.model}/fsed']
+            points['fsed'] = np.asarray(fsed)
+
+        if self.model in ['petitcode-hot-clear', 'petitcode-hot-cloudy']:
+            co_ratio = h5_file[f'models/{self.model}/co']
+            points['co'] = np.asarray(co_ratio)
+
         h5_file.close()
 
         return points
